
"""
Test cases for the movie recommender system
"""

import unittest
import pandas as pd
import movies

class LoadTests(unittest.TestCase):
    """Test functions concerned with loading and preparing the dataset"""

    @staticmethod
    def toy_ratings():
        """Return a toy dataframe with ratings"""
        return pd.DataFrame({
            "userId": [1, 1, 2, 2, 1],
            "movieId": [1, 2, 1, 3, 4],
            "rating": [3, 1, 4, 3, 5],
            "timestamp": [1, 2, 7, 5, 4],
        },
        columns=["userId", "movieId", "rating", "timestamp"])

    def test_collect_user_context(self):
        """Check that ratings are correctly aggregated"""
        rating = self.toy_ratings()
        user_movies = movies.collect_user_context(rating)

        self.assertEqual(user_movies[1], [1, 4])
        self.assertEqual(user_movies[2], [3, 1])
        self.assertEqual(set(user_movies.keys()), {1, 2})

    def test_collect_user_context_min_rating(self):
        """Check the min rating threshold"""
        rating = self.toy_ratings()
        user_movies = movies.collect_user_context(rating, min_rating=5)

        self.assertEqual(user_movies[1], [4])
        self.assertEqual(set(user_movies.keys()), {1})
